@@ -383,7 +383,7 @@ class DALLE(nn.Module):
 
             image_len = image.shape[1]
             image_emb = self.image_emb(image)
-            image_emb += self.image_pos_emb(torch.arange(image_len, device = device))
+            image_emb += self.image_pos_emb(image_emb)
 
             tokens = torch.cat((tokens, image_emb), dim = 1)
 
